using System;

namespace MaryJane
{
    public class Rig : MVRScript
    {
        public override void Init()
        {
            try
            {
                if (containingAtom.type != "Person")
                {
                    SuperController.LogError("Please attach to a Person Atom");
                }
                else
                {
                    SetControllers();
                }
            }
            catch (Exception e)
            {
                SuperController.LogError("Exception caught: " + e);
            }
        }

        protected void SetControllers()
        {
            try
            {
                //Neck (the master atom) - Position On, Rotation On
                FreeControllerV3 controller = containingAtom.GetStorableByID("neckControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.On, FreeControllerV3.RotationState.On);

                //Head - Position Comply, Rotation On
                controller = containingAtom.GetStorableByID("headControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Comply, FreeControllerV3.RotationState.On);

                //Chest - Position Comply, Rotation Comply. Parent Link to Neck
                controller = containingAtom.GetStorableByID("chestControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Comply, FreeControllerV3.RotationState.Comply);
                SetControllerLinkTo(controller, containingAtom.name, "neckControl");

                //Hip - Position Comply, Rotation Comply, Parent Link to Chest
                controller = containingAtom.GetStorableByID("hipControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Comply, FreeControllerV3.RotationState.Comply);
                SetControllerLinkTo(controller, containingAtom.name, "chestControl");

                //Right Elbow - Position On, Rotation Off, Parent Link to Neck
                controller = containingAtom.GetStorableByID("rElbowControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.On, FreeControllerV3.RotationState.Off);
                SetControllerLinkTo(controller, containingAtom.name, "neckControl");

                //Left Elbow - Position On, Rotation Off, Parent Link to Neck
                controller = containingAtom.GetStorableByID("lElbowControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.On, FreeControllerV3.RotationState.Off);
                SetControllerLinkTo(controller, containingAtom.name, "neckControl");

                //Right Hand - Position Off, Rotation Comply
                controller = containingAtom.GetStorableByID("rHandControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Off, FreeControllerV3.RotationState.Comply);

                //Left Hand - Position Off, Rotation Comply
                controller = containingAtom.GetStorableByID("lHandControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Off, FreeControllerV3.RotationState.Comply);

                //Right Knee -Position On, Rotation Off, Parent Link to Neck
                controller = containingAtom.GetStorableByID("rKneeControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.On, FreeControllerV3.RotationState.Off);
                SetControllerLinkTo(controller, containingAtom.name, "neckControl");

                //Left Knee -Position On, Rotation Off, Parent Link to Neck
                controller = containingAtom.GetStorableByID("lKneeControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.On, FreeControllerV3.RotationState.Off);
                SetControllerLinkTo(controller, containingAtom.name, "neckControl");

                //Right Foot - Position Comply, Rotation On
                controller = containingAtom.GetStorableByID("rFootControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Comply, FreeControllerV3.RotationState.On);

                //Left Foot - Position Comply, Rotation On
                controller = containingAtom.GetStorableByID("lFootControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Comply, FreeControllerV3.RotationState.On);

                //Right Toe -Position Off, Rotation Comply
                controller = containingAtom.GetStorableByID("rToeControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Off, FreeControllerV3.RotationState.Comply);

                //Left Toe -Position Off, Rotation Comply
                controller = containingAtom.GetStorableByID("lToeControl") as FreeControllerV3;
                SetControllerState(controller, FreeControllerV3.PositionState.Off, FreeControllerV3.RotationState.Comply);                
            }
            catch (Exception e)
            {
                SuperController.LogError("Exception caught: " + e);
            }
        }

        protected void SetControllerState(FreeControllerV3 controller, FreeControllerV3.PositionState positionState, FreeControllerV3.RotationState rotationState)
        {
            controller.currentPositionState = positionState;
            controller.currentRotationState = rotationState;
        }

        protected void SetControllerLinkTo(FreeControllerV3 controller, string linkToAtom, string linkToRigidbody)
        {
            controller.SetLinkToAtom(linkToAtom);
            controller.SetLinkToRigidbodyObject(linkToRigidbody);
            if (controller.linkToAtomSelectionPopup != null)
            {
                controller.linkToAtomSelectionPopup.currentValue = linkToAtom;
                controller.linkToSelectionPopup.currentValue = linkToRigidbody;
            }
        }
    }
}

